import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemIcon from "@material-ui/core/ListItemIcon";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import ListItemText from "@material-ui/core/ListItemText";
import Checkbox from "@material-ui/core/Checkbox";
import IconButton from "@material-ui/core/IconButton";

const useStyles = makeStyles(theme => ({
  root: {
    width: "100%",
    maxWidth: 360,
    backgroundColor: theme.palette.background.paper,
    color: "#666"
  }
}));

export default function SearchEPCompCurriculum(props) {
  const classes = useStyles();
  const [checked, setChecked] = React.useState([]);
  const [checkedWithLabel, setCheckedWithLabel] = React.useState([]);

  const handleToggle = (value, label) => () => {
    const currentIndex = checked.indexOf(value);
    const newChecked = [...checked];
    const newCheckedWithLabel = [...checkedWithLabel]; 

    if (currentIndex === -1) {
      newChecked.push(value);
      newCheckedWithLabel.push({
        label: label, 
        value: value, 
      });
    } else {
      newChecked.splice(currentIndex, 1);
      newCheckedWithLabel.splice(currentIndex, 1);
    }

    setChecked(newChecked);
    setCheckedWithLabel(newCheckedWithLabel)

    props.onChange("curriculum", newCheckedWithLabel)
  };
  const filtrosComponente = [
    { exemplo: "Arte", value: "3" },
    { exemplo: "Biologia", value: "5" },
    { exemplo: "Ciências da Natureza", value: "6" },
    { exemplo: "Direitos Humanos", value: "20" },
    { exemplo: "Educação Ambiental", value: "21" },
    { exemplo: "Educação do Campo", value: "22" },
    { exemplo: "Educação Especial", value: "23" },
    { exemplo: "Educação Física", value: "7" },
    { exemplo: "Educação Indígena", value: "24" },
    { exemplo: "Educação Quilombola", value: "25" },
    { exemplo: "Educação Sexual", value: "26" },
    { exemplo: "Ensino Religioso", value: "16" },
    { exemplo: "Filosofia", value: "8" },
    { exemplo: "Física", value: "9" },
    { exemplo: "Geografia", value: "10" },
    { exemplo: "História", value: "11" },
    { exemplo: "Informática", value: "18" },
    { exemplo: "Língua Espanhola", value: "1" },
    { exemplo: "Língua Inglesa", value: "2" },
    { exemplo: "Língua Portuguesa", value: "4" },
    { exemplo: "Matemática", value: "12" },
    { exemplo: "Outras Línguas", value: "15" },
    { exemplo: "Outros", value: "17" },
    { exemplo: "Química", value: "13" },
    { exemplo: "Sociologia", value: "14" }
  ];

  return (
    <List className={classes.root}>
      {filtrosComponente.map(item => {
        const labelId = `checkbox-list-label-${item.value}`;

        return (
          <ListItem
            key={item.exemplo}
            role={undefined}
            dense
            button
            onClick={handleToggle(item.value, item.exemplo)}
          >
            <ListItemIcon>
              <Checkbox
                edge="start"
                checked={checked.indexOf(item.value) !== -1}
                tabIndex={-1}
                disableRipple
                inputProps={{ "aria-labelledby": labelId }}
              />
            </ListItemIcon>
            <ListItemText id={labelId} primary={item.exemplo} />
            <ListItemSecondaryAction>
              <IconButton edge="end" aria-label="comments"></IconButton>
            </ListItemSecondaryAction>
          </ListItem>
        );
      })}
    </List>
  );
}
