import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemIcon from "@material-ui/core/ListItemIcon";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import ListItemText from "@material-ui/core/ListItemText";
import Checkbox from "@material-ui/core/Checkbox";
import IconButton from "@material-ui/core/IconButton";

const useStyles = makeStyles(theme => ({
  root: {
    width: "100%",
    maxWidth: 360,
    backgroundColor: theme.palette.background.paper,
    color: "#666"
  }
}));

export default function SearchEPIdiomas(props) {
  const classes = useStyles();
  const [checked, setChecked] = React.useState([]);
  const [checkedWithLabel, setCheckedWithLabel] = React.useState([]);

  const handleToggle = (value, label) => () => {
    const currentIndex = checked.indexOf(value);
    const newChecked = [...checked];
    const newCheckedWithLabel = [...checkedWithLabel];

    if (currentIndex === -1) {
      newChecked.push(value);
      newCheckedWithLabel.push({
        label: label,
        value: value,
      });
    } else {
      newChecked.splice(currentIndex, 1);
      newCheckedWithLabel.splice(currentIndex, 1);
    }

    setChecked(newChecked);
    setCheckedWithLabel(newCheckedWithLabel)

    props.onChange("languages", newCheckedWithLabel)
  };
  const filtrosIdiomas = [
    { value: "5", exemplo: "Alemão" },
    { value: "3", exemplo: "Espanhol" },
    { value: "4", exemplo: "Francês" },
    { value: "2", exemplo: "Inglês" },
    { value: "6", exemplo: "Italiano" },
    { value: "9", exemplo: "Japonês" },
    { value: "19", exemplo: "LIBRAS" },
    { value: "7", exemplo: "Mandarim" },
    { value: "10", exemplo: "Outro" },
    { value: "1", exemplo: "Português" },
    { value: "8", exemplo: "Russo" }
  ];

  return (
    <List className={classes.root}>
      {filtrosIdiomas.map(item => {
        const labelId = `checkbox-list-label-${item.value}`;

        return (
          <ListItem
            key={item.exemplo}
            role={undefined}
            dense
            button
            onClick={handleToggle(item.value, item.exemplo)}
          >
            <ListItemIcon>
              <Checkbox
                edge="start"
                checked={checked.indexOf(item.value) !== -1}
                tabIndex={-1}
                disableRipple
                inputProps={{ "aria-labelledby": labelId }}
              />
            </ListItemIcon>
            <ListItemText id={labelId} primary={item.exemplo} />
            <ListItemSecondaryAction>
              <IconButton edge="end" aria-label="comments"></IconButton>
            </ListItemSecondaryAction>
          </ListItem>
        );
      })}
    </List>
  );
}
