import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemIcon from "@material-ui/core/ListItemIcon";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import ListItemText from "@material-ui/core/ListItemText";
import Checkbox from "@material-ui/core/Checkbox";
import IconButton from "@material-ui/core/IconButton";

const useStyles = makeStyles(theme => ({
  root: {
    width: "100%",
    maxWidth: 360,
    backgroundColor: theme.palette.background.paper,
    color: "#666"
  }
}));

export default function SearchEPTiposRec(props) {
  const classes = useStyles();
  const [checked, setChecked] = React.useState([]);
  const [checkedWithLabel, setCheckedWithLabel] = React.useState([]);

  const handleToggle = (value, label) => () => {
    const currentIndex = checked.indexOf(value);
    const newChecked = [...checked];
    const newCheckedWithLabel = [...checkedWithLabel];

    if (currentIndex === -1) {
      newChecked.push(value);
      newCheckedWithLabel.push({
        label: label,
        value: value,
      });
    } else {
      newChecked.splice(currentIndex, 1);
      newCheckedWithLabel.splice(currentIndex, 1);
    }

    setChecked(newChecked);
    setCheckedWithLabel(newCheckedWithLabel)

    props.onChange("types", newCheckedWithLabel)
  };
  const filtrosTipos = [
    { value: "5", exemplo: "Animação" },
    { value: "20", exemplo: "Aplicativo móvel" },
    { value: "17", exemplo: "Apresentação" },
    { value: "7", exemplo: "Áudio" },
    { value: "4", exemplo: "Experimento prático" },
    { value: "1", exemplo: "Imagem" },
    { value: "18", exemplo: "Infográfico" },
    { value: "19", exemplo: "Jogo" },
    { value: "21", exemplo: "Livro digital" },
    { value: "2", exemplo: "Mapa" },
    { value: "15", exemplo: "Outros" },
    { value: "3", exemplo: "Software Educacional" },
    { value: "6", exemplo: "Texto" },
    { value: "8", exemplo: "Vídeo" },
    { value: "13", exemplo: "Website externo" },
    { value: "22", exemplo: "Plano de Aula" },
  ];

  return (
    <List className={classes.root}>
      {filtrosTipos.map(item => {
        const labelId = `checkbox-list-label-${item.value}`;

        return (
          <ListItem
            key={item.exemplo}
            role={undefined}
            dense
            button
            onClick={handleToggle(item.value, item.exemplo)}
          >
            <ListItemIcon>
              <Checkbox
                edge="start"
                checked={checked.indexOf(item.value) !== -1}
                tabIndex={-1}
                disableRipple
                inputProps={{ "aria-labelledby": labelId }}
              />
            </ListItemIcon>
            <ListItemText id={labelId} primary={item.exemplo} />
            <ListItemSecondaryAction>
              <IconButton edge="end" aria-label="comments"></IconButton>
            </ListItemSecondaryAction>
          </ListItem>
        );
      })}
    </List>
  );
}
