import React, { useState } from "react";
import { withStyles } from "@material-ui/core/styles";
import MuiExpansionPanel from "@material-ui/core/Accordion";
import MuiExpansionPanelSummary from "@material-ui/core/AccordionSummary";
import MuiExpansionPanelDetails from "@material-ui/core/AccordionActions";
import Typography from "@material-ui/core/Typography";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import SearchEPCompCurriculum from "./SearchEPCompCurriculum";
import SearchEPTiposRec from "./SearchEPTiposRec";
import SearchEPEtapasEns from "./SesrchEPEtapasEns";
import SearchEPIdiomas from "./SearchEPIdiomas";
import { TextField } from "@material-ui/core";
import Grid from '@material-ui/core/Grid';
import CircularProgress from '@material-ui/core/CircularProgress';
import Paper from '@material-ui/core/Paper';
import styled from 'styled-components';

import './ExpansionPanel.css'

const ExpansionPanel = withStyles({
  root: {
    border: "1px solid rgba(0, 0, 0, .125)",
    boxShadow: "none",
    '.MuiButtonBase-root': {
      paddingInline: "0 !important"
    },
    "&:not(:last-child)": {
      borderBottom: 0
    },
    "&:before": {
      display: "none"
    },
    "&$expanded": {
      margin: "auto"
    }
  },
  expanded: {}
})(MuiExpansionPanel);

const ExpansionPanelSummary = withStyles({
  root: {
    color: "#666",
    marginBottom: -1,
    minHeight: 56,
    backgroundColor: "#fff",


    "&$expanded": {
      minHeight: 56,
      backgroundColor: "#fff"
    }
  },
  content: {
    "&$expanded": {
      margin: "12px 0"
    }
  },
  expanded: {}
})(MuiExpansionPanelSummary);

const TesteTypography = withStyles({
  root: {
    fontSize: "17px"
  }
})(Typography);

const ExpansionPanelDetails = withStyles(theme => ({
  root: {
    // padding: theme.spacing(2)
  }
}))(MuiExpansionPanelDetails);

export default function SearchExpansionPanel(props) {
  const [keyWords, setKeyWords] = useState("");
  const [errorInKeyWord, setErrorInKeyWord] = useState({
    message: "",
    state: false
  })

  const onKeyPressed = (e) => {
    if (e.key === "Enter") {
      if (keyWords.length === 0) {
        setErrorInKeyWord({
          state: true,
          message: "Preencha o campo"
        })
      }
      else
        props.onChange("tag", keyWords)
    }
  }

  const HandleChangeText = (e) => {
    if (errorInKeyWord.state)
      setErrorInKeyWord({
        state: false,
        message: ""
      })
    setKeyWords(e.target.value);
  }

  return (
    <MainPaper square elevation={4}>
      <link
        href="https://fonts.googleapis.com/css?family=Roboto:400,500&display=swap"
        rel="stylesheet"
      />

      <ExpansionPanel square>
        <ExpansionPanelSummary
          aria-controls="panel1d-content"
          id="panel1d-header"
        >
          <Grid
            container
            direction="row"
            justify="space-between"
          >
            <Grid item >
              <Typography
                style={{
                  fontSize: "18px",
                  textTransform: "uppercase",
                  fontWeight: "500",
                }}
              >
                Filtros
              </Typography>
            </Grid>
            <Grid item>
              {
                props.onFiltering ? <CircularProgress size={24} color="secondary" /> : null
              }
            </Grid>
          </Grid>
        </ExpansionPanelSummary>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary 
          expandIcon={<ExpandMoreIcon />}

          aria-controls="panel2d-content"
          id="panel2d-header"
        >
          <TesteTypography>Componentes Curriculares</TesteTypography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails>
          <div>
            <SearchEPCompCurriculum onChange={props.onChange} />
          </div>
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          expandIcon={<ExpandMoreIcon />}
          aria-controls="panel3d-content"
          id="panel3d-header"
        >
          <Typography>Tipos de Recurso</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails>
          <SearchEPTiposRec onChange={props.onChange} />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          aria-controls="panel4d-content"
          expandIcon={<ExpandMoreIcon />}
          id="panel4d-header"
        >
          <Typography>Etapas de Ensino</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails>
          <SearchEPEtapasEns onChange={props.onChange} />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          aria-controls="panel5d-content"
          expandIcon={<ExpandMoreIcon />}
          id="panel5d-header"
        >
          <Typography>Idiomas</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails>
          <SearchEPIdiomas onChange={props.onChange} />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          aria-controls="panel6d-content"
          expandIcon={<ExpandMoreIcon />}
          id="panel6d-header"
        >
          <Typography>Palavra-Chave</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails>
          <TextField
            label="Palavra chave + enter  "
            id="outlined-margin-dense"
            variant="outlined"
            onChange={e => HandleChangeText(e)}
            onKeyDown={e => onKeyPressed(e)}
            error={errorInKeyWord.state}
            helperText={errorInKeyWord.state ? errorInKeyWord.message : ""}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>
    </MainPaper>
  );
}

const MainPaper = styled(Paper)`
  /* height: 150px; */
  text-align: center;
  background-color: #fff;
  margin-top: 5px;
  margin-bottom: 30px;
  color: #666;
  .textInfo{
    text-align: start;
  }
`;
