import React from 'react';
import styled from 'styled-components';
import Paper from '@material-ui/core/Paper';
import Grid from '@material-ui/core/Grid';
import Chip from '@material-ui/core/Chip';
import Button from "@material-ui/core/Button";

export default function FilterSummary
  ({ curriculumComponents, typeOfResources, languages, teachingStage, tag, onButtonClicked }) {
  return (
    <FilterSummaryPaper square elevation={4}>
      <h3 className="title">
        Resumo dos filtros colocados
      </h3>
      <Grid container direction='column' spacing={2}>
        {
          curriculumComponents.length >= 1 ?
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Componentes curriculares:
              </Grid>
                <Grid item>
                  {
                    curriculumComponents.map((item) => {
                      return (
                        <StyledChip key={new Date().toISOString() + item.value} size="small" label={item.label} />
                      )
                    })
                  }
                </Grid>
              </Grid>
            </Grid>
            :
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Componentes curriculares:
              </Grid>
                <Grid item>
                  <StyledChip size="small" label="Nenhum selecionado" />
                </Grid>
              </Grid>
            </Grid>
        }
        {
          typeOfResources.length >= 1 ?
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Tipos de recursos:
              </Grid>
                <Grid item>
                  {
                    typeOfResources.map((item) => {
                      return (
                        <StyledChip key={new Date().toISOString() + item.value} size="small" label={item.label} />
                      )
                    })
                  }
                </Grid>
              </Grid>
            </Grid>
            :
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Tipos de recursos:
                </Grid>
                <Grid item>
                  <StyledChip size="small" label="Nenhum selecionado" />
                </Grid>
              </Grid>
            </Grid>
        }
        {
          teachingStage.length >= 1 ?
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Etapas de ensino:
              </Grid>
                <Grid item>
                  {
                    teachingStage.map((item) => {
                      return (
                        <StyledChip key={new Date().toISOString() + item.value} size="small" label={item.label} />
                      )
                    })
                  }
                </Grid>
              </Grid>
            </Grid>
            :
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Etapas de ensino:
                </Grid>
                <Grid item>
                  <StyledChip size="small" label="Nenhum selecionado" />
                </Grid>
              </Grid>
            </Grid>
        }
        {
          languages.length >= 1 ?
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Idiomas:
              </Grid>
                <Grid item>
                  {
                    languages.map((item) => {
                      return (
                        <StyledChip key={new Date().toISOString() + item.value} size="small" label={item.label} />
                      )
                    })
                  }
                </Grid>
              </Grid>
            </Grid>
            :
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Idiomas:
                </Grid>
                <Grid item>
                  <StyledChip size="small" label="Nenhum selecionado" />
                </Grid>
              </Grid>
            </Grid>
        }
        {
          tag.length >= 1 ?
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Palavra chave:
                </Grid>
                <Grid item>
                  <StyledChip size="small" label={tag} />
                </Grid>
              </Grid>
            </Grid>
            :
            <Grid item>
              <Grid container direction='row' spacing={1} alignItems='center'>
                <Grid item>
                  Palavra chave:
                </Grid>
                <Grid item>
                  <StyledChip size="small" label="Nenhum selecionado" />
                </Grid>
              </Grid>
            </Grid>
        }
        <Grid item>
          <StyledButton variant="contained" onClick={onButtonClicked}>
            <span className="text">
              Aplicar filtro
            </span>
          </StyledButton>
        </Grid>
      </Grid>
    </FilterSummaryPaper>
  )
}

const FilterSummaryPaper = styled(Paper)`
  background-color: #fff;
  margin-top: 5px;
  margin-bottom: 30px;
  padding: 0.5em 1em;
  .title{
    text-transform: uppercase;
    color: #666; 
    font-weight: 500; 
  }
`
const StyledButton = styled(Button)`
  background-color: #ff7f00 !important;
  .text{
    color: white;
  }
`

const StyledChip = styled(Chip)`
  margin: 0.2em
`
